package com.gprinter.utils;

import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Rect;

/* loaded from: com_gprinter_utils.jar:com/gprinter/utils/PicFromPrintUtils.class */
public class PicFromPrintUtils {
    public static byte[] draw2PxPoint(Bitmap bit) {
        byte[] data = new byte[16290];
        int k = 0;
        for (int j = 0; j < 15; j++) {
            int i = k;
            int k2 = k + 1;
            data[i] = 27;
            int k3 = k2 + 1;
            data[k2] = 42;
            int k4 = k3 + 1;
            data[k3] = 33;
            int k5 = k4 + 1;
            data[k4] = 104;
            int k6 = k5 + 1;
            data[k5] = 1;
            for (int i2 = 0; i2 < 360; i2++) {
                for (int m = 0; m < 3; m++) {
                    for (int n = 0; n < 8; n++) {
                        byte b = px2Byte(i2, (j * 24) + (m * 8) + n, bit);
                        int i3 = k6;
                        data[i3] = (byte) (data[i3] + data[k6] + b);
                    }
                    k6++;
                }
            }
            int i4 = k6;
            k = k6 + 1;
            data[i4] = 10;
        }
        return data;
    }

    public static byte[] pic2PxPoint(Bitmap bitmap, int printWidth) {
        int width = ((printWidth + 7) / 8) * 8;
        int height = (bitmap.getHeight() * width) / bitmap.getWidth();
        Bitmap bit = BitmapUtils.resizeImage(bitmap, width, height);
        int cmdHead = (bit.getHeight() / 8) * 5;
        int pixNum = (bit.getHeight() / 8) * 3 * bit.getWidth();
        byte[] data = new byte[pixNum + cmdHead];
        int k = 0;
        for (int i = 0; i < bit.getHeight() / 24; i++) {
            int i2 = k;
            int k2 = k + 1;
            data[i2] = 27;
            int k3 = k2 + 1;
            data[k2] = 42;
            int k4 = k3 + 1;
            data[k3] = 33;
            int k5 = k4 + 1;
            data[k4] = (byte) (bit.getWidth() % 256);
            int k6 = k5 + 1;
            data[k5] = (byte) (bit.getWidth() / 256);
            for (int x = 0; x < bit.getWidth(); x++) {
                for (int m = 0; m < 3; m++) {
                    byte[] by = new byte[8];
                    for (int n = 0; n < 8; n++) {
                        byte b = px2Byte(x, (((i * 24) + (m * 8)) + 7) - n, bit);
                        by[n] = b;
                    }
                    data[k6] = (byte) changePointPx1(by);
                    k6++;
                }
            }
            int i3 = k6;
            k = k6 + 1;
            data[i3] = 10;
        }
        return data;
    }

    public static byte[] pic8PxPoint(Bitmap bitmap, int printWidth) {
        int width = ((printWidth + 7) / 8) * 8;
        int height = (bitmap.getHeight() * width) / bitmap.getWidth();
        Bitmap bit = BitmapUtils.resizeImage(bitmap, width, height);
        int cmdHead = (bit.getHeight() / 8) * 7;
        int pixNum = (bit.getHeight() / 8) * 3 * bit.getWidth();
        byte[] data = new byte[pixNum + cmdHead];
        int k = 0;
        for (int i = 0; i < bit.getHeight() / 8; i++) {
            int i2 = k;
            int k2 = k + 1;
            data[i2] = 27;
            int k3 = k2 + 1;
            data[k2] = 42;
            int k4 = k3 + 1;
            data[k3] = 0;
            int k5 = k4 + 1;
            data[k4] = (byte) (bit.getWidth() % 256);
            int k6 = k5 + 1;
            data[k5] = (byte) (bit.getWidth() / 256);
            for (int x = 0; x < bit.getWidth(); x++) {
                byte[] by = new byte[8];
                for (int n = 0; n < 8; n++) {
                    byte b = px2Byte(x, ((i * 8) + 7) - n, bit);
                    by[n] = b;
                }
                data[k6] = (byte) changePointPx1(by);
                k6++;
            }
            int i3 = k6;
            int k7 = k6 + 1;
            data[i3] = 27;
            int k8 = k7 + 1;
            data[k7] = 74;
            k = k8 + 1;
            data[k8] = 15;
        }
        return data;
    }

    public static byte px2Byte(int x, int y, Bitmap bit) {
        byte b;
        int pixel = bit.getPixel(x, y);
        int red = (pixel & 16711680) >> 16;
        int green = (pixel & 65280) >> 8;
        int blue = pixel & 255;
        int gray = RGB2Gray(red, green, blue);
        if (gray < 128) {
            b = 1;
        } else {
            b = 0;
        }
        return b;
    }

    private static int RGB2Gray(int r, int g, int b) {
        int gray = (int) ((0.299d * r) + (0.587d * g) + (0.114d * b));
        return gray;
    }

    public static Bitmap compressPic(Bitmap bitmapOrg) {
        int width = bitmapOrg.getWidth();
        int height = bitmapOrg.getHeight();
        Bitmap targetBmp = Bitmap.createBitmap(360, 360, Bitmap.Config.ARGB_8888);
        Canvas targetCanvas = new Canvas(targetBmp);
        targetCanvas.drawColor(-1);
        targetCanvas.drawBitmap(bitmapOrg, new Rect(0, 0, width, height), new Rect(0, 0, 360, 360), (Paint) null);
        return targetBmp;
    }

    public static Bitmap compressBitmap(Bitmap bitmapOrg) {
        int width = bitmapOrg.getWidth();
        int height = bitmapOrg.getHeight();
        float scaleWidth = 360 / width;
        float scaleHeight = 360 / height;
        Matrix matrix = new Matrix();
        matrix.postScale(scaleWidth, scaleHeight);
        Bitmap resizedBitmap = Bitmap.createBitmap(bitmapOrg, 0, 0, width, height, matrix, true);
        return resizedBitmap;
    }

    public static int changePointPx1(byte[] arry) {
        int v = 0;
        for (int j = 0; j < arry.length; j++) {
            if (arry[j] == 1) {
                v |= 1 << j;
            }
        }
        return v;
    }

    public byte changePointPx(byte[] arry) {
        byte v = 0;
        for (int i = 0; i < 8; i++) {
            v = (byte) (v + v + arry[i]);
        }
        return v;
    }

    public byte[] getPicPx(Bitmap bitmap) {
        int[] pixels = new int[bitmap.getWidth() * bitmap.getHeight()];
        bitmap.getPixels(pixels, 0, bitmap.getWidth(), 0, 0, bitmap.getWidth(), bitmap.getHeight());
        for (int clr : pixels) {
            int red = (clr & 16711680) >> 16;
            int green = (clr & 65280) >> 8;
            int blue = clr & 255;
            System.out.println("r=" + red + ",g=" + green + ",b=" + blue);
        }
        return null;
    }
}
